@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::Autocomplete::Globals::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::Autocomplete::Globals::VERSION = '0.23';
+  $Reply::Plugin::Autocomplete::Globals::VERSION = '0.24';
 }
 use strict;
 use warnings;
@@ -13,6 +13,8 @@ use base 'Reply::Plugin';
 
 use Package::Stash;
 
+use Reply::Util qw($fq_ident_rx $fq_varname_rx);
+
 
 sub new {
     my $class = shift;
@@ -26,7 +28,7 @@ sub tab_handler {
     my $self = shift;
     my ($line) = @_;
 
-    my ($maybe_var) = $line =~ /([\$\@\%\&\*]\s*[0-9A-Z_a-z:]*)$/;
+    my ($maybe_var) = $line =~ /($fq_varname_rx)$/;
     return unless $maybe_var;
     $maybe_var =~ s/\s+//g;
 
@@ -84,8 +86,7 @@ sub _recursive_symbols {
         # to not also block out punctuation variables.
         # XXX fix for unicode
         # XXX fix for variables like ${^GLOBAL_PHASE}
-        next unless $name =~ /^[A-Z_a-z][0-9A-Z_a-z]*(?:::)?$/
-                 || length($name) == 1;
+        next unless $name =~ /^$fq_ident_rx(?:::)?$/ || length($name) == 1;
 
         if ($name =~ s/::$//) {
             my $next = Package::Stash->new(join('::', $stash_name, $name));
@@ -121,7 +122,7 @@ Reply::Plugin::Autocomplete::Globals - tab completion for global variables
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
